PicToken

Enum PicToken 

pub enum PicToken {
Show 15 variants Digit, ZeroSuppress, ZeroInsert, AsteriskFill, Space, Comma, Slash, DecimalPoint, Currency, LeadingPlus, LeadingMinus, TrailingPlus, TrailingMinus, Credit, Debit,
}
Pattern tokens for edited PIC clauses.

Each variant represents a formatting symbol in an edited PICTURE clause, used during decode and encode of edited numeric fields.

Variants



Digit

Numeric digit (9) - always displays



ZeroSuppress

Zero suppression (Z) - displays space if leading zero



ZeroInsert

Zero insert (0) - always displays ‘0’



AsteriskFill

Asterisk fill () - displays ‘’ for leading zeros



Space

Blank space (B)



Comma

Literal comma



Slash

Literal slash



DecimalPoint

Decimal point



Currency

Currency symbol ($)



LeadingPlus

Leading plus sign



LeadingMinus

Leading minus sign



TrailingPlus

Trailing plus sign



TrailingMinus

Trailing minus sign



Credit

Credit (CR) - two characters



Debit

Debit (DB) - two characters