pub enum Codepage {
ASCII,
CP037,
CP273,
CP500,
CP1047,
CP1140,
}Expand description
Codepage identifier for EBCDIC/ASCII character encoding. Character encoding specification supported by copybook-rs.
Variants
ASCII
ASCII encoding.
CP037
EBCDIC Code Page 037 (US/Canada).
CP273
EBCDIC Code Page 273 (Germany/Austria).
CP500
EBCDIC Code Page 500 (International).
CP1047
EBCDIC Code Page 1047 (Open Systems).
CP1140
EBCDIC Code Page 1140 (US/Canada with Euro).
Implementations
Sourceimpl Codepage
impl Codepage
Sourcepub const fn variants() -> &'static [Codepage; 6]
pub const fn variants() -> &'static [Codepage; 6]
Return all supported codepages in their canonical display order.
Sourcepub const fn code_page_number(self) -> Option<u16>
pub const fn code_page_number(self) -> Option<u16>
Return the numeric codepage identifier, if this is an EBCDIC page.
Sourcepub const fn description(self) -> &'static str
pub const fn description(self) -> &'static str
Return a human-readable description.
Sourcepub fn parse(input: &str) -> Result<Codepage, ParseCodepageError>
pub fn parse(input: &str) -> Result<Codepage, ParseCodepageError>
Parse a codepage and reject unknown values.
Errors
Returns ParseCodepageError when input is not a supported
codepage spelling.