pub fn read_record(
input: &mut impl Read,
format: RecordFormat,
lrecl: Option<u32>,
) -> Result<Option<Vec<u8>>>Expand description
Read one record using the selected framing format.
Errors
Returns an error when the delegated framing read fails or when fixed framing is missing its LRECL.