pub fn decode_packed_decimal_with_scratch(
data: &[u8],
digits: u16,
scale: i16,
signed: bool,
scratch: &mut ScratchBuffers,
) -> Result<SmallDecimal>Expand description
Optimized packed decimal decoder using scratch buffers Minimizes allocations by reusing digit buffer
Errors
Returns an error when the packed decimal data has an invalid length or contains bad digit/sign nibbles.