encode_overpunch_byte

Function encode_overpunch_byte 

pub fn encode_overpunch_byte(
    digit: u8,
    is_negative: bool,
    codepage: Codepage,
    policy: ZeroSignPolicy,
) -> Result<u8>
Encode overpunch byte for the given digit, sign, and codepage

Errors

Returns an error if the digit is invalid or the encoding fails.