pub fn decode_record_with_raw_data(
schema: &Schema,
data: &[u8],
options: &DecodeOptions,
raw_data_with_header: Option<&[u8]>,
record_index: u64,
) -> Result<Value>Expand description
Decode a record with optional raw data for RDW format
Errors
Returns an error if field decoding fails or the raw payload is inconsistent with the schema.